========================================
Yet Another Kyoto Cabinet Python Binding
========================================

:author: Yasunobu OKAMURA

License
=======

::

  Yet Another Kyoto Cabinet Python Binding
  Copyright (C) 2013  Yasunobu OKAMURA

  Kyoto Cabinet
  Copyright (C) 2009-2011 FAL Labs
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.

Install
=======

::

   python setup.py build
   python setup.py install

Basic use
=========

::

  import yakc
  d = yakc.KyotoDB('test.kch')
  d['a'] = '123'


